#ifndef NT2_INCLUDE_FUNCTIONS_BSEARCH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BSEARCH_HPP_INCLUDED

#include <nt2/interpol/include/functions/bsearch.hpp>

#endif
